@@ -12,9 +12,12 @@ class UploadLineageToEDC:
     def upload_lineage(self):
         print("Uploading lineage to EDC with config files in >%s<" % self.config_directory)
         for file in glob.glob(self.config_directory + "config_for_*.json"):
-            print("Lineage processing with configuration file >%s<" % file)
+            print("=== START === Lineage processing with configuration file >%s<" % file)
             load_json = load_json_metadata.ConvertJSONtoEDCLineage(configuration_file=file)
-            load_json.main(ignore_metafile_creation=True)
+            result = load_json.main(ignore_metafile_creation=True)
+            print(result)
+            print("=== END === Lineage processing with configuration file >%s<" % file)
+            return result
 
 
 if __name__ == "__main__":
